function out = Rec1900(Rec)
%
% ABAQUS element definition output to MATLAB
% 
% Syntax
%     #Rec# = Fil2str('*.fil');
%     #out# = Rec1900(#Rec#)
%
% Description
%     Read element definition output from the results (*.fil) file
%     generated from the ABAQUS finite element software. The asterisk (*)
%     is replaced by the name of the results file. The record key for
%     element definition output is 1900. See section "Results file output
%     format" in ABAQUS Analysis User's manual for more details.
%     The following option with parameter has to be specified in the ABAQUS
%     input file for the results (*.fil) file to be created:
%         ...
%         *FILE FORMAT, ASCII
%         ...
%     NOTE: The results file (*.fil) must be placed in the same directory
%     with the MATLAB source files in order to be processed.
%     
% Input parameters
%     #Rec# (string) is an one-row string containing the ASCII code of the
%         ABAQUS results (*.fil) file. It is generated by the function
%         Fil2str.m.
% 
% Output parameters
%     #out# ([#n# x #m#]) is a cell array containing the attributes of
%         the record key 1900 as follows:
%         Column  1    Element number. 
%         Column  2    Element type. 
%         Column  3    First node on the element. 
%         Column  4    Second node on the element. 
%         Column  5    etc. 
%         where #n# is the number of elements and #m#-2 is the number of
%         nodes per element. If the results file does not contain the
%         desired output, #out# will be an empty array
%
% _________________________________________________________________________
% Copyright (c) 2016
%     George Papazafeiropoulos
%     Captain, Infrastructure Engineer, Hellenic Air Force
%     Civil Engineer, M.Sc., Ph.D. candidate, NTUA
%     Email: gpapazafeiropoulos@yahoo.gr
%     Website: http://users.ntua.gr/gpapazaf/
%

ind = strfind(Rec,'I 41900'); % record key for element output (1900)
if isempty(ind)
    out=[];
    return;
end
nextpos=numel('I 41900')+1;
EleNum=zeros(numel(ind),1);
EleType=char(zeros(numel(ind),8));
% Initialize record length matrix
NW=zeros(numel(ind),1);
for i=1:numel(ind)
    % find the record length (NW)
    Rec2=Rec(ind(i)-7:ind(i));
    indNW=strfind(Rec2,'*'); % record starts with *
    % ensure that the record exists and that the record type key is at location 2
    if isempty(indNW) || indNW>3
        ind(i)=NaN;
        continue;
    end
    % number of digits of record length
    ind1=indNW+2;
    ind2=indNW+3;
    a1=str2num(Rec2(ind1:ind2));
    % Record length (NW)
    ind1=ind1+2;
    ind2=ind2+a1;
    NW(i)=str2num(Rec2(ind1:ind2));
end
EleNodes=zeros(numel(ind),max(NW)-4);
for i=1:numel(ind)
    % number of digits of element number
    ind1=ind(i)+nextpos;
    ind2=ind(i)+nextpos+1;
    a1=str2num(Rec(ind1:ind2));
    % Element number
    ind1=ind1+2;
    ind2=ind2+a1;
    EleNum(i)=str2num(Rec(ind1:ind2));
    % Element type
    ind1=ind1+1+a1;
    ind2=ind2+9;
    EleType(i,:)=Rec(ind1:ind2);
    % Element connectivity
    for j=1:NW(i)-4
        % number of digits of Element node
        ind1=ind2+2;
        ind2=ind2+3;
        a2=str2num(Rec(ind1:ind2));
        % Element node
        ind1=ind1+2;
        ind2=ind2+a2;
        EleNodes(i,j)=str2num(Rec(ind1:ind2));
    end
end
% Assemply of matrices for output
out=[num2cell(EleNum) cellstr(EleType) num2cell(EleNodes)];

end

