function out = Rec1980(Rec)
%
% ABAQUS modal output to MATLAB
% 
% Syntax
%     #Rec# = Fil2str('*.fil');
%     #out# = Rec1980(#Rec#)
%
% Description
%     Read modal output from the results (*.fil) file generated from the
%     ABAQUS finite element software. The asterisk (*) is replaced by the
%     name of the results file. The record key for modal output is 1980 (in
%     ABAQUS/Standard) and is written once per eigenvalue in a natural
%     frequency extraction step. See section "Results file output format"
%     in ABAQUS Analysis User's manual for more details.
%     The following options with parameters have to be specified in the
%     ABAQUS input file for the results (*.fil) file to be created and
%     contain frequency analysis results (#n# is the number of requested
%     eigenvalues):
%         ...
%         *FREQUENCY
%         #n#
%         *FILE FORMAT, ASCII
%         ...
%     NOTE: The results file (*.fil) must be placed in the same directory
%     with the MATLAB source files in order to be processed.
%     
% Input parameters
%     #Rec# (string) is an one-row string containing the ASCII code of the
%         ABAQUS results (*.fil) file. It is generated by the function
%         Fil2str.m.
% 
% Output parameters
%     #out# ([#n# x 16]) is a double array containing the attributes of the
%         record key 1980 as follows:
%         Column  1    Eigenvalue number. 
%         Column  2    Eigenvalue. 
%         Column  3    Generalized mass. 
%         Column  4    Composite damping. 
%         Column  5    Participation factor for degree of freedom 1. 
%         Column  6    Effective mass for degree of freedom 1. 
%         Column  7    Participation factor for degree of freedom 2. 
%         Column  8    Effective mass for degree of freedom 2. 
%         Column  9    Participation factor for degree of freedom 3. 
%         Column 10    Effective mass for degree of freedom 3. 
%         Column 11    Participation factor for degree of freedom 4. 
%         Column 12    Effective mass for degree of freedom 4. 
%         Column 13    Participation factor for degree of freedom 5. 
%         Column 14    Effective mass for degree of freedom 5. 
%         Column 15    Participation factor for degree of freedom 6. 
%         Column 16    Effective mass for degree of freedom 6. 
%         where #n# is the number of requested eigenvalues in the frequency
%         extraction step. If the results file does not contain the desired
%         output, #out# will be an empty array
%
% _________________________________________________________________________
% Copyright (c) 2016
%     George Papazafeiropoulos
%     Captain, Infrastructure Engineer, Hellenic Air Force
%     Civil Engineer, M.Sc., Ph.D. candidate, NTUA
%     Email: gpapazafeiropoulos@yahoo.gr
%     Website: http://users.ntua.gr/gpapazaf/
%

ind = strfind(Rec,'I 41980'); % record key for modal (1980)
if isempty(ind)
    out=[];
    return;
end
nextpos=numel('I 41980')+1;
for i=1:numel(ind)
    % check ind
    Rec2=Rec(ind(i)-7:ind(i));
    indNW=strfind(Rec2,'*'); % record starts with *
    % ensure that the record exists and that the record type key is at location 2
    if isempty(indNW) || indNW>3
        ind(i)=NaN;
        continue;
    end
end
ind(isnan(ind))=[];
NEigVal=zeros(numel(ind),1);
EigVal=zeros(numel(ind),1);
GenMass=zeros(numel(ind),1);
CompDamp=zeros(numel(ind),1);
PartFdof=zeros(numel(ind),6);
Meffdof=zeros(numel(ind),6);
for i=1:numel(ind)
    % number of digits of eigenvalue number
    ind1=ind(i)+nextpos;
    ind2=ind(i)+nextpos+1;
    a1=str2num(Rec(ind1:ind2));
    % Eigenvalue number
    ind1=ind1+2;
    ind2=ind2+a1;
    NEigVal(i)=str2num(Rec(ind1:ind2));
    % Eigenvalue
    ind1=ind1+1+a1;
    ind2=ind2+23;
    EigVal(i)=str2num(Rec(ind1:ind2));
    % Generalized mass
    ind1=ind1+23;
    ind2=ind2+23;
    GenMass(i)=str2num(Rec(ind1:ind2));
    % Composite damping
    ind1=ind1+23;
    ind2=ind2+23;
    CompDamp(i)=str2num(Rec(ind1:ind2));
    % Participation factor for degree of freedom 1
    ind1=ind1+23;
    ind2=ind2+23;
    PartFdof(i,1)=str2num(Rec(ind1:ind2));
    % Effective mass for degree of freedom 1
    ind1=ind1+23;
    ind2=ind2+23;
    Meffdof(i,1)=str2num(Rec(ind1:ind2));
    % Participation factor for degree of freedom 2
    ind1=ind1+23;
    ind2=ind2+23;
    PartFdof(i,2)=str2num(Rec(ind1:ind2));
    % Effective mass for degree of freedom 2
    ind1=ind1+23;
    ind2=ind2+23;
    Meffdof(i,2)=str2num(Rec(ind1:ind2));
    % Participation factor for degree of freedom 3
    ind1=ind1+23;
    ind2=ind2+23;
    PartFdof(i,3)=str2num(Rec(ind1:ind2));
    % Effective mass for degree of freedom 3
    ind1=ind1+23;
    ind2=ind2+23;
    Meffdof(i,3)=str2num(Rec(ind1:ind2));
    % Participation factor for degree of freedom 4
    ind1=ind1+23;
    ind2=ind2+23;
    PartFdof(i,4)=str2num(Rec(ind1:ind2));
    % Effective mass for degree of freedom 4
    ind1=ind1+23;
    ind2=ind2+23;
    Meffdof(i,4)=str2num(Rec(ind1:ind2));
    % Participation factor for degree of freedom 5
    ind1=ind1+23;
    ind2=ind2+23;
    PartFdof(i,5)=str2num(Rec(ind1:ind2));
    % Effective mass for degree of freedom 5
    ind1=ind1+23;
    ind2=ind2+23;
    Meffdof(i,5)=str2num(Rec(ind1:ind2));
    % Participation factor for degree of freedom 6
    ind1=ind1+23;
    ind2=ind2+23;
    PartFdof(i,6)=str2num(Rec(ind1:ind2));
    % Effective mass for degree of freedom 6
    ind1=ind1+23;
    ind2=ind2+23;
    Meffdof(i,6)=str2num(Rec(ind1:ind2));
end
% Assemply of matrices for output
out=[NEigVal,EigVal,GenMass,CompDamp,PartFdof,Meffdof];

end

