function out = Rec19(Rec)
%
% ABAQUS energy (summed over element) output to MATLAB
% 
% Syntax
%     #Rec# = Fil2str('*.fil');
%     #out# = Rec19(#Rec#)
%
% Description
%     Read energy (summed over element) output from the results (*.fil)
%     file generated from the ABAQUS finite element software. The asterisk
%     (*) is replaced by the name of the results file. The record key for
%     energy (summed over element) output is 19. See section "Results file
%     output format" in ABAQUS Analysis User's manual for more details.
%     The following options with parameters have to be specified in the
%     ABAQUS input file for the results (*.fil) file to be created and to
%     contain energy (summed over element) results:
%         ...
%         *FILE FORMAT, ASCII
%         *EL FILE
%         ELEN
%         ...
%     NOTE: The results file (*.fil) must be placed in the same directory
%     with the MATLAB source files in order to be processed.
%     
% Input parameters
%     #Rec# (string) is an one-row string containing the ASCII code of the
%         ABAQUS results (*.fil) file. It is generated by the function
%         Fil2str.m.
% 
% Output parameters
%     #out# ([#n# x 10]) is a double array containing the attributes of
%         the record key 19 as follows:
%         Column  1    Kinetic energy. 
%         Column  2    Strain energy. 
%         Column  3    Plastic dissipation.
%         Column  4    Creep dissipation.
%         Column  5    Viscous dissipation, not including dissipation due
%         to stabilization.
%         Column  6    Static dissipation (due to stabilization).
%         Column  7    Artificial strain energy.
%         Column  8    Electrostatic energy.
%         Column  9    Electrical energy dissipated in a conductor.
%         Column  10    Damage dissipation.
%         where #n# is the number of elements multiplied by the number of
%         increments. If the results file does not contain the desired
%         output, #out# will be an empty array
%
% _________________________________________________________________________
% Copyright (c) 2016
%     George Papazafeiropoulos
%     Captain, Infrastructure Engineer, Hellenic Air Force
%     Civil Engineer, M.Sc., Ph.D. candidate, NTUA
%     Email: gpapazafeiropoulos@yahoo.gr
%     Website: http://users.ntua.gr/gpapazaf/
%

ind = strfind(Rec,'I 219D'); % record key for element energy (summed over element) output (19)
if isempty(ind)
    out=[];
    return;
end
nextpos=numel('I 219')+1;
% Initialize record length matrix
NW=zeros(numel(ind),1);
for i=1:numel(ind)
    % find the record length (NW)
    Rec2=Rec(ind(i)-7:ind(i));
    indNW=strfind(Rec2,'*'); % record starts with *
    % ensure that the record exists and that the record type key is at location 2
    if isempty(indNW) || indNW>3
        ind(i)=NaN;
        continue;
    end
    % number of digits of record length
    ind1=indNW+2;
    ind2=indNW+3;
    a1=str2num(Rec2(ind1:ind2));
    % Record length (NW)
    ind1=ind1+2;
    ind2=ind2+a1;
    NW(i)=str2num(Rec2(ind1:ind2));
end
% remove ind and NW values which do not correspond to output
NW(isnan(ind))=[]; 
ind(isnan(ind))=[];
% Initialize
EleOut=zeros(numel(ind),max(NW)-2);
for i=1:numel(ind)
    ind2=ind(i)+nextpos-2;
    % Element energies (summed over element)
    for j=1:NW(i)-2
        % energy (summed over element)
        ind1=ind2+2;
        ind2=ind2+23;
        EleOut(i,j)=str2num(Rec(ind1:ind2));
    end
end
% Assembly of matrices for output
out=EleOut;

end

