function out = Rec31(Rec)
%
% ABAQUS concrete failure output to MATLAB
% 
% Syntax
%     #Rec# = Fil2str('*.fil');
%     #out# = Rec31(#Rec#)
%
% Description
%     Read concrete failure output from the results (*.fil) file generated
%     from the ABAQUS finite element software. The asterisk (*) is replaced
%     by the name of the results file. The record key for concrete failure
%     output is 31 (only in ABAQUS/Standard). See section "Results file
%     output format" in ABAQUS Analysis User's manual for more details.
%     The following options with parameters have to be specified in the
%     ABAQUS input file for the results (*.fil) file to be created and to
%     contain concrete failure results:
%         ...
%         *FILE FORMAT, ASCII
%         *EL FILE
%         CONF
%         ...
%     NOTE: The results file (*.fil) must be placed in the same directory
%     with the MATLAB source files in order to be processed.
%     
% Input parameters
%     #Rec# (string) is an one-row string containing the ASCII code of the
%         ABAQUS results (*.fil) file. It is generated by the function
%         Fil2str.m.
% 
% Output parameters
%     #out# ([#n# x 2]) is a cell array containing the attributes of
%         the record key 31 as follows:
%         Column  1  -  Serial number (increasing from 1 to #n#)
%         Column  2    Summary of the state of a concrete material point.
%         This is the number of cracks or 1 if the concrete has crushed.
%         where #n# is the number of elements multiplied by the number of
%         integration points multiplied by the number of increments. If the
%         results file does not contain the desired output, #out# will be
%         an empty array
%
% _________________________________________________________________________
% Copyright (c) 2016
%     George Papazafeiropoulos
%     Captain, Infrastructure Engineer, Hellenic Air Force
%     Civil Engineer, M.Sc., Ph.D. candidate, NTUA
%     Email: gpapazafeiropoulos@yahoo.gr
%     Website: http://users.ntua.gr/gpapazaf/
%

ind = strfind(Rec,'I 231A'); % record key for element concrete failure output (31)
if isempty(ind)
    out=[];
    return;
end
nextpos=numel('I 231')+1;
for i=1:numel(ind)
    % check ind
    Rec2=Rec(ind(i)-7:ind(i));
    indNW=strfind(Rec2,'*'); % record starts with *
    % ensure that the record exists and that the record type key is at location 2
    if isempty(indNW) || indNW>3
        ind(i)=NaN;
        continue;
    end
end
ind(isnan(ind))=[];
EleOut=char(zeros(numel(ind),8));
for i=1:numel(ind)
    ind2=ind(i)+nextpos;
    % Element concrete failure
    ind1=ind2;
    ind2=ind2+7;
    EleOut(i,:)=Rec(ind1:ind2);
end
% Assembly of matrices for output
out=[num2cell((1:numel(ind))') cellstr(EleOut)];

end

