function out = Rec38(Rec)
%
% ABAQUS mass concentration (mass diffusion analysis) output to MATLAB
% 
% Syntax
%     #Rec# = Fil2str('*.fil');
%     #out# = Rec38(#Rec#)
%
% Description
%     Read mass concentration (mass diffusion analysis) output from the
%     results (*.fil) file generated from the ABAQUS finite element
%     software. The asterisk (*) is replaced by the name of the results
%     file. The record key for mass concentration output is 38 (only in
%     ABAQUS/Standard). See section "Results file output format" in ABAQUS
%     Analysis User's manual for more details.
%     The following options with parameters have to be specified in the
%     ABAQUS input file for the results (*.fil) file to be created and to
%     contain mass concentration results:
%         ...
%         *FILE FORMAT, ASCII
%         *EL FILE
%         CONC
%         ...
%     NOTE: The results file (*.fil) must be placed in the same directory
%     with the MATLAB source files in order to be processed.
%     
% Input parameters
%     #Rec# (string) is an one-row string containing the ASCII code of the
%         ABAQUS results (*.fil) file. It is generated by the function
%         Fil2str.m.
% 
% Output parameters
%     #out# ([#n# x 1]) is a double array containing the attributes of
%         the record key 38 as follows:
%         Column  1    Concentration.
%         where #n# is the number of elements multiplied by the number of
%         integration points multiplied by the number of increments. If the
%         results file does not contain the desired output, #out# will be
%         an empty array
%
% _________________________________________________________________________
% Copyright (c) 2016
%     George Papazafeiropoulos
%     Captain, Infrastructure Engineer, Hellenic Air Force
%     Civil Engineer, M.Sc., Ph.D. candidate, NTUA
%     Email: gpapazafeiropoulos@yahoo.gr
%     Website: http://users.ntua.gr/gpapazaf/
%

ind = strfind(Rec,'I 238D'); % record key for element mass concentration output (38)
if isempty(ind)
    out=[];
    return;
end
nextpos=numel('I 238')+1;
for i=1:numel(ind)
    % check ind
    Rec2=Rec(ind(i)-7:ind(i));
    indNW=strfind(Rec2,'*'); % record starts with *
    % ensure that the record exists and that the record type key is at location 2
    if isempty(indNW) || indNW>3
        ind(i)=NaN;
        continue;
    end
end
ind(isnan(ind))=[];
EleOut=zeros(numel(ind),1);
for i=1:numel(ind)
    ind2=ind(i)+nextpos-2;
    % Element mass concentration
    ind1=ind2+2;
    ind2=ind2+23;
    EleOut(i)=str2num(Rec(ind1:ind2));
end
% Assembly of matrices for output
out=EleOut;

end

