function out = Rec61(Rec)
%
% ABAQUS element status output to MATLAB
% 
% Syntax
%     #Rec# = Fil2str('*.fil');
%     #out# = Rec61(#Rec#)
%
% Description
%     Read element status output from the results (*.fil) file generated
%     from the ABAQUS finite element software. The asterisk (*) is replaced
%     by the name of the results file. The record key for element status
%     output is 61 (only in ABAQUS/Explicit). See section "Results file
%     output format" in ABAQUS Analysis User's manual for more details.
%     The following options with parameters have to be specified in the
%     ABAQUS input file for the results (*.fil) file to be created and to
%     contain element status results:
%         ...
%         *FILE FORMAT, ASCII
%         *EL FILE
%         STATUS
%         ...
%     NOTE: The results file (*.fil) must be placed in the same directory
%     with the MATLAB source files in order to be processed.
%     
% Input parameters
%     #Rec# (string) is an one-row string containing the ASCII code of the
%         ABAQUS results (*.fil) file. It is generated by the function
%         Fil2str.m.
% 
% Output parameters
%     #out# ([#n# x 1]) is a double array containing the attributes of
%         the record key 61 as follows:
%         Column  1    Status of element (shear failure model, tensile
%         failure model, porous failure criterion, brittle failure model,
%         Johnson-Cook plasticity model, and VUMAT). The status of an
%         element is 1.0 if the element is active, 0.0 if the element is
%         not.
%         where #n# is the number of elements multiplied by the number of
%         increments. If the results file does not contain the desired
%         output, #out# will be an empty array
%
% _________________________________________________________________________
% Copyright (c) 2016
%     George Papazafeiropoulos
%     Captain, Infrastructure Engineer, Hellenic Air Force
%     Civil Engineer, M.Sc., Ph.D. candidate, NTUA
%     Email: gpapazafeiropoulos@yahoo.gr
%     Website: http://users.ntua.gr/gpapazaf/
%

ind = strfind(Rec,'I 261D'); % record key for element element status output (61)
if isempty(ind)
    out=[];
    return;
end
nextpos=numel('I 261')+1;
for i=1:numel(ind)
    % check ind
    Rec2=Rec(ind(i)-7:ind(i));
    indNW=strfind(Rec2,'*'); % record starts with *
    % ensure that the record exists and that the record type key is at location 2
    if isempty(indNW) || indNW>3
        ind(i)=NaN;
        continue;
    end
end
ind(isnan(ind))=[];
EleOut=zeros(numel(ind),1);
for i=1:numel(ind)
    ind2=ind(i)+nextpos-2;
    % Element element status
    ind1=ind2+2;
    ind2=ind2+23;
    EleOut(i)=str2num(Rec(ind1:ind2));
end
% Assembly of matrices for output
out=EleOut;

end

