function out = Rec110(Rec)
%
% ABAQUS reactive fluid total volume output to MATLAB
% 
% Syntax
%     #Rec# = Fil2str('*.fil');
%     #out# = Rec110(#Rec#)
%
% Description
%     Read reactive fluid total volume output from the results (*.fil) file
%     generated from the ABAQUS finite element software. The asterisk (*)
%     is replaced by the name of the results file. The record key for
%     reactive fluid total volume output is 110 (only in ABAQUS/Standard).
%     See section "Results file output format" in ABAQUS Analysis User's
%     manual for more details.
%     The following options with parameters have to be specified in the
%     ABAQUS input file for the results (*.fil) file to be created and to
%     contain reactive fluid total volume results:
%         ...
%         *FILE FORMAT, ASCII
%         *NODE FILE
%         RVT
%         ...
%     NOTE: The results file (*.fil) must be placed in the same directory
%     with the MATLAB source files in order to be processed.
%     
% Input parameters
%     #Rec# (string) is an one-row string containing the ASCII code of the
%         ABAQUS results (*.fil) file. It is generated by the function
%         Fil2str.m.
% 
% Output parameters
%     #out# ([#n# x 2]) is a double array containing the attributes of
%         the record key 110 as follows:
%         Column  1    Node number. 
%         Column  2    Reaction fluid total volume. 
%         where #n# is the number of nodes multiplied by the number of
%         increments. If the results file does not contain the desired
%         output, #out# will be an empty array
%
% _________________________________________________________________________
% Copyright (c) 2016
%     George Papazafeiropoulos
%     Captain, Infrastructure Engineer, Hellenic Air Force
%     Civil Engineer, M.Sc., Ph.D. candidate, NTUA
%     Email: gpapazafeiropoulos@yahoo.gr
%     Website: http://users.ntua.gr/gpapazaf/
%

ind = strfind(Rec,'I 3110I'); % record key for node reactive fluid total volume output (110)
if isempty(ind)
    out=[];
    return;
end
nextpos=numel('I 3110')+1;
for i=1:numel(ind)
    % check the record
    Rec2=Rec(ind(i)-7:ind(i));
    indNW=strfind(Rec2,'*'); % record starts with *
    % ensure that the record exists and that the record type key is at location 2
    if isempty(indNW) || indNW>3
        ind(i)=NaN;
        continue;
    end
end
ind(isnan(ind))=[];
% Initialize
NodeNum=zeros(numel(ind),1);
NodeOut=zeros(numel(ind),1);
for i=1:numel(ind)
    % number of digits of node number
    ind1=ind(i)+nextpos;
    ind2=ind(i)+nextpos+1;
    a1=str2num(Rec(ind1:ind2));
    % Node number
    ind1=ind1+2;
    ind2=ind2+a1;
    NodeNum(i)=str2num(Rec(ind1:ind2));
    % reactive fluid total volume
    ind1=ind2+2;
    ind2=ind2+23;
    NodeOut(i)=str2num(Rec(ind1:ind2));
end
% Assemply of matrices for output
out=[NodeNum NodeOut];

end

