function out = Rec214(Rec)
%
% ABAQUS internal flux output to MATLAB
% 
% Syntax
%     #Rec# = Fil2str('*.fil');
%     #out# = Rec214(#Rec#)
%
% Description
%     Read internal flux output from the results (*.fil) file generated
%     from the ABAQUS finite element software. The asterisk (*) is replaced
%     by the name of the results file. The record key for internal flux
%     output is 214 (only in ABAQUS/Standard). See section "Results file
%     output format" in ABAQUS Analysis User's manual for more details.
%     The following options with parameters have to be specified in the
%     ABAQUS input file for the results (*.fil) file to be created and to
%     contain internal flux results:
%         ...
%         *FILE FORMAT, ASCII
%         *NODE FILE
%         RFLE
%         ...
%     NOTE: The results file (*.fil) must be placed in the same directory
%     with the MATLAB source files in order to be processed.
%     
% Input parameters
%     #Rec# (string) is an one-row string containing the ASCII code of the
%         ABAQUS results (*.fil) file. It is generated by the function
%         Fil2str.m.
% 
% Output parameters
%     #out# ([#n# x #m#]) is a double array containing the attributes of
%         the record key 214 as follows:
%         Column  1    Node number. 
%         Column  2    Flux, excluding external flux. 
%         Column  3    Etc (for heat shells)
%         where #n# is the number of nodes multiplied by the number of
%         increments and #m#-1 is the number of internal fluxes per node.
%         If the results file does not contain the desired output, #out#
%         will be an empty array
%
% _________________________________________________________________________
% Copyright (c) 2016
%     George Papazafeiropoulos
%     Captain, Infrastructure Engineer, Hellenic Air Force
%     Civil Engineer, M.Sc., Ph.D. candidate, NTUA
%     Email: gpapazafeiropoulos@yahoo.gr
%     Website: http://users.ntua.gr/gpapazaf/
%

ind = strfind(Rec,'I 3214I'); % record key for node internal flux output (214)
if isempty(ind)
    out=[];
    return;
end
nextpos=numel('I 3214')+1;
% Initialize record length matrix
NW=zeros(numel(ind),1);
for i=1:numel(ind)
    % find the record length (NW)
    Rec2=Rec(ind(i)-7:ind(i));
    indNW=strfind(Rec2,'*'); % record starts with *
    % ensure that the record exists and that the record type key is at location 2
    if isempty(indNW) || indNW>3
        ind(i)=NaN;
        continue;
    end
    % number of digits of record length
    ind1=indNW+2;
    ind2=indNW+3;
    a1=str2num(Rec2(ind1:ind2));
    % Record length (NW)
    ind1=ind1+2;
    ind2=ind2+a1;
    NW(i)=str2num(Rec2(ind1:ind2));
end
% remove ind and NW values which do not correspond to output
NW(isnan(ind))=[]; 
ind(isnan(ind))=[];
% Initialize
NodeNum=zeros(numel(ind),1);
NodeOut=zeros(numel(ind),max(NW)-3);
for i=1:numel(ind)
    % number of digits of node number
    ind1=ind(i)+nextpos;
    ind2=ind(i)+nextpos+1;
    a1=str2num(Rec(ind1:ind2));
    % Node number
    ind1=ind1+2;
    ind2=ind2+a1;
    NodeNum(i)=str2num(Rec(ind1:ind2));
    % node internal fluxes
    for j=1:NW(i)-3
        % internal flux
        ind1=ind2+2;
        ind2=ind2+23;
        NodeOut(i,j)=str2num(Rec(ind1:ind2));
    end
end
% Assemply of matrices for output
out=[NodeNum NodeOut];

end

